Learn R Programming

AntibodyTiters (version 0.1.24)

toyABT: Production of an xlsx file with toy data.

Description

AntibodyTiters requires the input xlsx files be in a specific format. This function produces a toy xlsx file in the format.

Usage

toyABT(fileName = "toy.xlsx", pmax = 7, patients = 20, 
    outsiderPercent = 2, NaPercent = 10, 
	Attrib = c("Sex", "Age", "VeryLow"), 
	attribFactors = list(c("F", "M"), c(18, 80), c(TRUE, FALSE)))

Arguments

fileName

a file name to be produced.

pmax

an integer (>=4 & <18) for specifying the maximam sampling point.

patients

an integer specifying the number of patients.

outsiderPercent

an integer specifying the percentage of patients with outsider values.

NaPercent

an integer specifying the percentage of patients with NA values.

Attrib

a character vector for the names of Attrib.

attribFactors

a list determining the values of Attrib. If the names of Attrib contained "Age", two numbers provided here are used as lower and upper limits.

Value

An xlsx file will be stored in the current directory.

Examples

Run this code
# NOT RUN {
# toyABT(fileName = "toy.xlsx", pmax = 9, patients = 120, 
# 	outsiderPercent = 2, NaPercent = 10, 
# 	Attrib = c("Sex", "Age", "VeryLow"), 
# 	attribFactors = list(c("F", "M"), c(18, 80), c(TRUE, FALSE)))
# The above command will create an excel file with toy data in the current directory. 
# }

Run the code above in your browser using DataLab